package redditi;

import java.io.FileReader;
import java.util.List;

import redditi.model.CalcolatoreRedditi;
import redditi.model.Scaglione;
import redditi.model.TipologiaContribuente;
import redditi.persistence.ScaglioniReader;
import redditi.persistence.NoTaxAreaReader;
import redditi.persistence.MyScaglioniReader;
import redditi.persistence.MyNoTaxAreaReader;
import redditi.ui.MainFrame;
import redditi.ui.controller.Controller;
import redditi.ui.controller.MyController;
import redditi.ui.controller.SwingUserInteractor;
import redditi.ui.controller.UserInteractor;

public class Program
{
	public static void main(String[] args)
	{
		Controller controller = null;
		UserInteractor userInteractor = new SwingUserInteractor();
		try {
			NoTaxAreaReader reader1 = new MyNoTaxAreaReader();
			List<TipologiaContribuente> listaTipologie;
			try (FileReader tipologieFile = new FileReader("No-tax area.txt")) {
				listaTipologie = reader1.leggiTipologieContribuenti(tipologieFile);
			}
			System.err.println(listaTipologie);

			ScaglioniReader reader2 = new MyScaglioniReader();
			List<Scaglione> listaScaglioni;
			try (FileReader scaglioniFile = new FileReader("Scaglioni.txt")) {
				listaScaglioni = reader2.leggiScaglioniReddito(scaglioniFile);
			}
			System.err.println(listaTipologie);
			
			CalcolatoreRedditi calcolatore = new CalcolatoreRedditi(listaScaglioni.toArray(new Scaglione[1]));
			System.out.println(calcolatore);
			System.out.println(calcolatore.formatta("Imposta lorda", calcolatore.calcolaImpostaLorda(40000, 8000)));
			System.out.println(calcolatore.formatta("imposta netta", calcolatore.calcolaImpostaNetta(1400,"20%")));

			controller = new MyController(userInteractor, listaTipologie, calcolatore);
			System.out.println(controller.calcolaImpostaLorda(40000, 8000));
			System.out.println(controller.calcolaImpostaNetta(1400,0.2));
			
			MainFrame mainFrame = new MainFrame(controller);
			mainFrame.setVisible(true);
			
		} catch (Exception e) {
			e.printStackTrace();
		}
	}
}