package redditi.persistence;

import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.io.Reader;
import java.text.NumberFormat;
import java.text.ParseException;
import java.util.ArrayList;
import java.util.List;
import java.util.Locale;
import java.util.NoSuchElementException;
import java.util.StringTokenizer;

import redditi.model.*;

public class MyNoTaxAreaReader implements NoTaxAreaReader {

	private List<TipologiaContribuente> lista;

	public MyNoTaxAreaReader() {
	}

	/*
	lavoratori dipendenti: 8.000
	aaaa: 5.000
	 */
	public List<TipologiaContribuente> leggiTipologieContribuenti(Reader reader)
			throws BadFileFormatException {
		if (reader == null)
			throw new IllegalArgumentException("reader");

		lista = new ArrayList<>();
		try {
			BufferedReader bufferedReader = new BufferedReader(reader);
			NumberFormat formatter = NumberFormat.getNumberInstance(Locale.ITALY);
			String line;
			while ((line = bufferedReader.readLine()) != null) {
				StringTokenizer tokenizer = new StringTokenizer(line, ":");
				String descrizione = tokenizer.nextToken().trim();
				String noTaxArea = tokenizer.nextToken().trim();
				// verifiche consistenza formato
				double sogliaNoTax = formatter.parse(noTaxArea).doubleValue();
				TipologiaContribuente tc = new TipologiaContribuente(descrizione, sogliaNoTax);
				lista.add(tc);
			}
		} catch (IOException | ParseException | NoSuchElementException e) {
			throw new BadFileFormatException(e + "Errore lettura tipologie e no-tax area");
		}
		return lista;

	}

	public static void main(String[] args) throws BadFileFormatException, IOException {
		NoTaxAreaReader reader = new MyNoTaxAreaReader();
		try (FileReader fileReader = new FileReader("No-tax area.txt")) {
			List<TipologiaContribuente> listaTipologie = reader.leggiTipologieContribuenti(fileReader);
			for (TipologiaContribuente tc : listaTipologie)
				System.out.println(tc);
		}
	}

}
