package redditi.persistence;

import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.io.Reader;
import java.text.NumberFormat;
import java.text.ParseException;
import java.util.ArrayList;
import java.util.List;
import java.util.Locale;
import java.util.NoSuchElementException;
import java.util.StringTokenizer;

import redditi.model.*;

public class MyScaglioniReader implements ScaglioniReader {

	private List<Scaglione> listaScaglioni;

	public MyScaglioniReader() {
	}

	/*
	0-15.000: 10%
	15.000-25.000: 25%
	25.000-45.000: 33%
	45.000-70.000: 38%
	70.000-oltre:  45%
	 */
	public List<Scaglione> leggiScaglioniReddito(Reader reader)
			throws BadFileFormatException {
		if (reader == null)
			throw new IllegalArgumentException("reader");

		listaScaglioni = new ArrayList<>();
		try {
			BufferedReader bufferedReader = new BufferedReader(reader);
			NumberFormat formatter = NumberFormat.getNumberInstance(Locale.ITALY);
			String line;
			while ((line = bufferedReader.readLine()) != null) {
				StringTokenizer tokenizer = new StringTokenizer(line, "-: \t");
				String min = tokenizer.nextToken().trim();
				String max = tokenizer.nextToken().trim();
				String perc = tokenizer.nextToken().trim();
				// verifiche consistenza formato
				double sogliaMin = formatter.parse(min).doubleValue();
				Scaglione scaglione = 
						max.equals("oltre") ? new Scaglione(sogliaMin, perc) 
										    : new Scaglione(sogliaMin, formatter.parse(max).doubleValue(), perc);
				listaScaglioni.add(scaglione);
			}
		} catch (IOException | ParseException | NoSuchElementException e) {
			throw new BadFileFormatException(e + "Errore lettura scaglioni");
		}
		return listaScaglioni;

	}

	public static void main(String[] args) throws BadFileFormatException, IOException {
		ScaglioniReader reader = new MyScaglioniReader();
		try (FileReader fileReader = new FileReader("Scaglioni.txt")) {
			List<Scaglione> listaScaglioni = reader.leggiScaglioniReddito(fileReader);
			for (Scaglione s : listaScaglioni)
				System.out.println(s);
		}
	}

}
