package redditi.ui;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Font;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.text.ParseException;

import javax.swing.Box;
import javax.swing.JComboBox;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextArea;
import javax.swing.JTextField;
import javax.swing.WindowConstants;

import redditi.model.TipologiaContribuente;
import redditi.ui.controller.Controller;

public class MainFrame extends JFrame implements ActionListener {

	private static final long serialVersionUID = 1L;

	private Controller controller;
	private JPanel mainPanel;
	
	private JComboBox<TipologiaContribuente> tipologieCombo;
	private JTextField redditoLordoField, redditoImponibileField, speseMedicheField;
	private JTextArea outputArea;
	private TipologiaContribuente[] arrayTipologie;
	
	public MainFrame(Controller controller) {
		this.controller = controller;
		arrayTipologie = this.controller.getListaTipologie().toArray(new TipologiaContribuente[1]);
		initGUI();
		setSize(450, 240);
	}

	private void initGUI() {

		mainPanel = new JPanel();
		getContentPane().add(mainPanel);

		setTitle("Dentinia Redditi");
		setDefaultCloseOperation(WindowConstants.EXIT_ON_CLOSE);

		tipologieCombo = new JComboBox<>(arrayTipologie);
		mainPanel.add(new JLabel("Tipologia"), BorderLayout.NORTH);
		mainPanel.add(tipologieCombo, BorderLayout.NORTH);
		
		Box box1 = Box.createVerticalBox();
		redditoLordoField = new JTextField(10); redditoLordoField.setText("0,00"); redditoLordoField.setHorizontalAlignment(JTextField.RIGHT);
		redditoImponibileField = new JTextField(10);   redditoImponibileField.setEditable(false); redditoImponibileField.setHorizontalAlignment(JTextField.RIGHT);
		redditoLordoField.setFont(new Font("Courier New", Font.BOLD, 12));
		redditoImponibileField.setFont(new Font("Courier New", Font.BOLD, 12));
		speseMedicheField = new JTextField(10); speseMedicheField.setText("0,00"); speseMedicheField.setHorizontalAlignment(JTextField.RIGHT);
		speseMedicheField.setFont(new Font("Courier New", Font.BOLD, 12));
		
		box1.add(new JLabel("Reddito lordo "), BorderLayout.NORTH);
		box1.add(redditoLordoField, BorderLayout.NORTH);
		box1.add(new JLabel(" Imponibile "), BorderLayout.NORTH);
		box1.add(redditoImponibileField, BorderLayout.NORTH);
		box1.add(new JLabel("Spese mediche "), BorderLayout.NORTH);
		box1.add(speseMedicheField, BorderLayout.NORTH);
		mainPanel.add(box1);
		
		outputArea = new JTextArea(6,60); outputArea.setEditable(false); outputArea.setBackground(Color.cyan);
		outputArea.setFont(new Font("Courier New", Font.BOLD, 11));
		mainPanel.add(outputArea, BorderLayout.CENTER);
		
		tipologieCombo.addActionListener(this);
		redditoLordoField.addActionListener(this);
		speseMedicheField.addActionListener(this);
	}

	@Override
	public void actionPerformed(ActionEvent e) {
		outputArea.setText("");
		TipologiaContribuente tipologia = (TipologiaContribuente) tipologieCombo.getSelectedItem();
		String importoString = (String) redditoLordoField.getText();
		String speseString = (String) speseMedicheField.getText();
		double reddito, spese;
		try {
			reddito = controller.getCalcolatoreRedditi().parse(importoString);
			spese = controller.getCalcolatoreRedditi().parse(speseString);
		}
		catch(ParseException e1){
			controller.getUserInteractor().showMessage("Gli importi devono essere numerici");
			return;
		}
		
		String impostaLorda = controller.calcolaImpostaLorda(reddito, tipologia.getnoTaxArea());
		String impostaNetta = controller.calcolaImpostaNetta(spese, controller.getAliquotaSpeseMediche());
		redditoImponibileField.setText(controller.getCalcolatoreRedditi().formatta("",
				controller.getCalcolatoreRedditi().getRedditoImponibile(reddito, tipologia.getnoTaxArea()))
		);		
		outputArea.append(impostaLorda+"\n");
		outputArea.append(impostaNetta+"\n");
	}	
}
