package redditi.tests.persistence;

import java.io.IOException;
import java.io.StringReader;
import java.util.List;

import static org.junit.Assert.*;

import org.junit.Test;

import redditi.model.*;
import redditi.persistence.*;

public class MyNoTaxAreaReaderTest {
	
	@Test
	public void testRead_ShouldSucceed() throws IOException, BadFileFormatException {
		String toRead = "asdf asdf: 9.123\n" +
				"fdsa fdsa: 1.987 \n";
		
		NoTaxAreaReader myReader = new MyNoTaxAreaReader();
		List<TipologiaContribuente> list = myReader.leggiTipologieContribuenti(new StringReader(toRead));
		
		assertEquals(2, list.size());
		
		TipologiaContribuente x;
		
		x = list.get(0);
		assertEquals("asdf asdf", x.getDenominazione());
		assertEquals(9123, x.getnoTaxArea(), 0.0001);
		
		x = list.get(1);
		assertEquals("fdsa fdsa", x.getDenominazione());
		assertEquals(1987, x.getnoTaxArea(), 0.0001);
	}
	
	@Test(expected=BadFileFormatException.class)
	public void testRead_ShouldFailForMissingTokenName() throws IOException, BadFileFormatException {
		String toRead = "9.123\n" +
				"fdsa fdsa:1.987\n";
		
		NoTaxAreaReader myReader = new MyNoTaxAreaReader();
		myReader.leggiTipologieContribuenti(new StringReader(toRead));
	}
	
	@Test(expected=BadFileFormatException.class)
	public void testRead_ShouldFailForMalformedNumber() throws IOException, BadFileFormatException {
		String toRead = "asdf asdf: xxx\n" +
				"fdsa fdsa: 1.987 \n";
		
		NoTaxAreaReader myReader = new MyNoTaxAreaReader();
		myReader.leggiTipologieContribuenti(new StringReader(toRead));
	}
}
